# -*- coding: utf-8 -*-
"""模块的注释"""

movies = [[1,2,['a', 'b', 'c']], "The Holy Grail", 1975, "The Life of Brian", 1979, "The Meaning of Life", 1983]


"""函数的注释"""
def print_lol(the_list):
    for item in the_list:
        if isinstance(item, list):
            print_lol(item)
        else:
            print(item)

print_lol(movies)
        





from distutils.core import setup
setup(
      name="xujian",
      version="1.0.0",
      py_modules = ['xujian'],
      author="xujian",
      author_email="xujian@gmail.com",
      url="http://www.xujian.com",
      description="My test module",
)
